# studio9.r sample code

# 1. Simulation of t-statistics:
# 2. Run one-sample t tests (two-sided, right-sided, left-sided)
# 3. Run a two-sample t-test for equal means

# ---------------------------- #
# Simulation: The t statistic of a normal sample should follow a t distribution with the correct degrees of freedom.

# Each simulation does the following
# 1. Generate nsamples values from Normal(mu0, sigma^2) distribution.
# 2. Compute the t statistic for H0: mu = mu0.
# Then we run 10000 simulations; plot a density histogram of the t statitisc and superimpose the graph of the pdf of t with nsamples-1 degrees of freedom.

# Set parameters
mu0 = 4
sigma = 3
nsamples = 8
nsimulations = 10000

# Run simulations, save the results in tstats
tstats = rep(0,nsimulations)
for (j in 1:nsimulations) {
  x = rnorm(nsamples, mu0, sigma)
  t = mean(x-mu0)/sqrt(var(x)/nsamples)
  tstats[j] = t
}

# Get x, y for the graph of the pdf
df = nsamples-1
x = seq(-4,4,0.001)
y = dt(x,df)

# Draw the density histogram (freq=FALSE) and graph
ymax = max(y)  # Used to set plot range
binwidth = .3  # For histogram. 0.3 binwidth determined by trial and error
breaks = seq(min(tstats), max(tstats)+binwidth, binwidth)
hist(tstats, breaks=breaks, xlim=c(-5,5), ylim=c(0,1.1*ymax), freq=FALSE)
lines(x,y,col='orange',lwd=2)

# ----------------------- #
# One-sample t-test

# Read the data in from a file
mu0 = 0  # Null hypothesis
x = read.table('studio9-onesampledata.txt', )
res2 = t.test(x,mu=mu0) # It's this easy: two-sided test
print(res2)

resR = t.test(x,mu=mu0, alternative='greater') # Left-sided test
print(resR)

resL = t.test(x,mu=mu0, alternative='less') # Left-sided test
print(resL)

#--------
# Check results by hand
data = x[,1]
nsamples = length(data)
df = nsamples - 1
t = (mean(data)-mu0)/sqrt(var(data)/nsamples)
p2 = 2*(1-pt(abs(t),df))
cat('Two-sided test: t:', t, 'p', p2, '\n')
pR = 1-pt(abs(t),df)
cat('Right-sided test: t:', t, 'p', pR, '\n')
pL = pt(abs(t),df)
cat('Left-sided test: t:', t, 'p', pL, '\n')
#----------

#----------------------#
# Two-sample t-test
x = c(10,12,13,12,9,8,16,12,22,13,8)
y = c(6,7,6,4,5,0,11,5,9,5,5,3,5,5,3,3,7,8,4,7,3,3)
res2 = t.test(x,y)  # Two-sided test. Note unequal lengths give decimal for df.
resR = t.test(x,y, alternative="greater")  # Right sided: first mean > second mean
print(resR)
resL = t.test(x,y, alternative="less")  # Left sided: first mean < second mean
print(resL)

#----------------------#
# You'll have to use the help in R or internet search to learn how to use the following. There is lots of sample code in class19.r
# chisq.text   --chi-square tests
# aov  -- ANOVA
